function fout = bedelevation(x,n_diff,parameters)
%fout = bedelevation(x,n_diff,parameters)
%   bed elevation as a function of position x
%   input arguments:
%       x:  position
%       n_diff: differentiation level, must admit choices n_diff = 0,1,2
%           with n_diff = 0 signifying the accumulation rate itself, n_diff
%           its first derivative etc.
%       parameters: the parameters.model structure passed to
%           outlet_evolve etc. If this contains a row vector
%           bed_coefficients and a row vector bed_exponents, the bed shape
%           is given by a `polynomial' of the form
%               fout = sum(bed_coefficients*x^bed_exponents)
%   output argument:
%       fout: the scaled bed elevation

if ~isfield(parameters,'bed_coefficients') || isempty(parameters.bed_coefficients)
    bed_coefficients = [1 -2];
else
    bed_coefficients = parameters.bed_coefficients;
end
if ~isfield(parameters,'bed_exponents') || isempty(parameters.bed_exponents)
    bed_exponents = [0 2];
else
    bed_exponents = parameters.bed_exponents;
end

X = repmat(x,1,length(bed_coefficients));
coeffs = repmat(bed_coefficients,length(x),1);
exponents = repmat(bed_exponents,length(x),1);

switch n_diff
    case 0
        fout = sum(coeffs.*X.^exponents,2);
    case 1
        exponents_mod = exponents-1;
        exponents_mod(exponents==0) = 1;
        fout = sum(coeffs.*exponents.*X.^exponents_mod,2);
    case 2
        exponents_mod = exponents-2;
        exponents_mod(exponents==0|exponents==1) = 1;
        fout = sum(coeffs.*exponents.*(exponents-1).*X.^exponents_mod,2);
    case 3
        exponents_mod = exponents-3;
        exponents_mod(exponents==0|exponents==1|exponents==2) = 1;
        fout = sum(coeffs.*exponents.*(exponents-1).*(exponents-2).*X.^exponents_mod,2);
end

end

