function fout = float_calve(zeta,n_diff,floatspec,parameters)
%fout = calve_phi(zeta,n_diff,floatspec,parameters)
%   Computes fraction of floatation thickness r*H_g attained by ice at the
%   calving front as a function of zeta = Lambda/H_g
%   Input arguemnts
%       zeta:   Dimensionless calving parameter for compatibility with Nick
%               et al 2010, here redundant as fout = 1/r always
%       n_diff: order of differentiation
%       floatspec:  Specifies whether formula for floating ice ('floating')
%               or grounded ice ('grounded') should be used
%       parameters: parameter structure, most contain parameters.model.r =
%               ratio of ice to water density

r = parameters.model.r;

switch n_diff
    case 0
        switch floatspec
            case 'grounded'
                fout = 1/r;
            case 'floating'
                error('"float_calve" can only be used with calving type "grounded calving", use "Nick_calve" otherwise');
        end
    case 1
         switch floatspec
            case 'grounded'
                fout = 0;
            case 'floating'
                error('"float_calve" can only be used with calving type "grounded calving", use "Nick_calve" otherwise');
        end       
end

end

